==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/kab.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Armud",
    "An error occurred while loading activities" : "Teḍra-d tuccḍa deg usali n irmuden",
    "No activity yet" : "Ulac armud yakan",
    "Load more activities" : "Sali-d ugar n irmuden",
    "Copied!" : "Yenɣel!",
    "Not supported!" : "Ur yettusefrak ara!",
    "Press ⌘-C to copy." : "Senned ɣef ⌘-C akken ad tneɣleḍ.",
    "Press Ctrl-C to copy." : "Senned ɣef Ctrl-C akken ad tneɣleḍ.",
    "{name} (invisible)" : "{isem} (uffir)",
    "{name} (restricted)" : "{isem} (yegdel)",
    "in {path}" : "deg {ubrid}",
    "This stream will show events like additions, changes & shares" : "Asuddem-agi issebdar ineḍruyen akka am tmerniwin, ibeddilen akked ibeḍḍuyen",
    "There are no events for this filter" : "Ulac ineḍruyen i testayt-agi",
    "Today" : "Ass-a",
    "Yesterday" : "Iḍelli",
    "Open file" : "Ldi afaylu",
    "Personal activity feed for %s" : "Asuddem n warmud udmawan n %s",
    "Your feed URL is invalid" : "URL n warmud inek  mačči d tameɣtut",
    "Your settings have been updated." : "Iɣewwaren-innek ttwaleqqmen",
    "Settings have been updated." : "Iɣewwaren ttwaleqqmen",
    "All activities" : "Akk irmuden",
    "By others" : "Sɣur wiyaḍ",
    "By you" : "Sɣur-k",
    "\"remote user\"" : "\"aseqdac anmeggag\"",
    "Activity notification for %s" : "Talɣut n warmud i %s",
    "Hello %s" : "Azul %s",
    "Hello %s," : "Azul %s,",
    "There was some activity at %s" : "Yella yiwen n urmud deg %s",
    "_and %n more _::_and %n more _" : ["akked %n nniḍen","akked %n nniḍen "],
    ", " : ", ",
    "%s and %s" : "%s akked %s",
    "Mail" : "Tirawt",
    "Stream" : "Asuddem",
    "This application enables users to view actions related to their files in Nextcloud." : "Asnas-ag ad yeǧǧ iseqdacen ad walin tigawin yeɛnan ifuyla-nnsen di Nextcloud.",
    "Activity feed" : "Asuddem n warmud",
    "Send activity emails" : "Azen imaylen n warmud",
    "Default settings" : "Iɣewwaren n lexṣas",
    "Configure the default activity settings for new users." : "Seɣwer iɣewwaren n warmud n lexṣas i iseqdacen imaynuten.",
    "List your own actions in the stream" : "Ssebder tigawin-inek ded usuddem",
    "Notify about your own actions via email" : "Azen-iyi-d imaylen n talɣut ɣef tigawin-iw",
    "You need to set up your email address before you can receive notification emails." : "Ilaq ad tesɣewreḍ tansa imayl iwakken ad tizmireḍ ad teṭṭfeḍ talɣut s imayl.",
    "Send emails:" : "Azen imaylen:",
    "Hourly" : "S usrag",
    "Daily" : "S wass",
    "Weekly" : "S umalas",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Fren ineḍruyen iwumi tebɣiḍ ad tawiḍ talɣut s imayl u i tebɣiḍ daɣen ad ten-twaliḍ deg usuddem n warmud inek.",
    "Choose which activities you want to see in your stream." : "Fren irmuden i tebɣiḍ ad twaliḍ deg usuddem-inek.",
    "Settings" : "Iɣewwaṛen",
    "Enable RSS feed" : "Ssermed asuddem RSS",
    "RSS feed" : "Asuddem RSS",
    "No more events to load" : "Dayen ulac ineḍruyen ara yettwazedmen",
    "Files" : "Ifuyla",
    "Activities" : "Irmuden",
    "Home" : "Asnubeg",
    "Activity notification" : "Alɣu n urmud"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/kab.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Armud",
    "An error occurred while loading activities" : "Teḍra-d tuccḍa deg usali n irmuden",
    "No activity yet" : "Ulac armud yakan",
    "Load more activities" : "Sali-d ugar n irmuden",
    "Copied!" : "Yenɣel!",
    "Not supported!" : "Ur yettusefrak ara!",
    "Press ⌘-C to copy." : "Senned ɣef ⌘-C akken ad tneɣleḍ.",
    "Press Ctrl-C to copy." : "Senned ɣef Ctrl-C akken ad tneɣleḍ.",
    "{name} (invisible)" : "{isem} (uffir)",
    "{name} (restricted)" : "{isem} (yegdel)",
    "in {path}" : "deg {ubrid}",
    "This stream will show events like additions, changes & shares" : "Asuddem-agi issebdar ineḍruyen akka am tmerniwin, ibeddilen akked ibeḍḍuyen",
    "There are no events for this filter" : "Ulac ineḍruyen i testayt-agi",
    "Today" : "Ass-a",
    "Yesterday" : "Iḍelli",
    "Open file" : "Ldi afaylu",
    "Personal activity feed for %s" : "Asuddem n warmud udmawan n %s",
    "Your feed URL is invalid" : "URL n warmud inek  mačči d tameɣtut",
    "Your settings have been updated." : "Iɣewwaren-innek ttwaleqqmen",
    "Settings have been updated." : "Iɣewwaren ttwaleqqmen",
    "All activities" : "Akk irmuden",
    "By others" : "Sɣur wiyaḍ",
    "By you" : "Sɣur-k",
    "Activity notification for %s" : "Talɣut n warmud i %s",
    "Hello %s" : "Azul %s",
    "Hello %s," : "Azul %s,",
    "There was some activity at %s" : "Yella yiwen n urmud deg %s",
    "_and %n more _::_and %n more _" : ["akked %n nniḍen","akked %n nniḍen "],
    "Mail" : "Tirawt",
    "Stream" : "Asuddem",
    "This application enables users to view actions related to their files in Nextcloud." : "Asnas-ag ad yeǧǧ iseqdacen ad walin tigawin yeɛnan ifuyla-nnsen di Nextcloud.",
    "Activity feed" : "Asuddem n warmud",
    "Send activity emails" : "Azen imaylen n warmud",
    "Default settings" : "Iɣewwaren n lexṣas",
    "Configure the default activity settings for new users." : "Seɣwer iɣewwaren n warmud n lexṣas i iseqdacen imaynuten.",
    "List your own actions in the stream" : "Ssebder tigawin-inek ded usuddem",
    "Notify about your own actions via email" : "Azen-iyi-d imaylen n talɣut ɣef tigawin-iw",
    "You need to set up your email address before you can receive notification emails." : "Ilaq ad tesɣewreḍ tansa imayl iwakken ad tizmireḍ ad teṭṭfeḍ talɣut s imayl.",
    "Send emails:" : "Azen imaylen:",
    "Hourly" : "S usrag",
    "Daily" : "S wass",
    "Weekly" : "S umalas",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Fren ineḍruyen iwumi tebɣiḍ ad tawiḍ talɣut s imayl u i tebɣiḍ daɣen ad ten-twaliḍ deg usuddem n warmud inek.",
    "Choose which activities you want to see in your stream." : "Fren irmuden i tebɣiḍ ad twaliḍ deg usuddem-inek.",
    "Settings" : "Iɣewwaṛen",
    "Enable RSS feed" : "Ssermed asuddem RSS",
    "RSS feed" : "Asuddem RSS",
    "No more events to load" : "Dayen ulac ineḍruyen ara yettwazedmen",
    "Activities" : "Irmuden",
    "Home" : "Asnubeg",
    "\"remote user\"" : "\"aseqdac anmeggag\"",
    "Activity notification" : "Alɣu n urmud",
    ", " : ", ",
    "%s and %s" : "%s akked %s",
    "Files" : "Ifuyla"
},
"nplurals=2; plural=(n != 1);");
